/*
  Copyright (c) 2013 Dirk Willrodt <willrodt@zbh.uni-hamburg.de>
  Copyright (c) 2013 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#ifndef WTREE_ENCSEQ_H
#define WTREE_ENCSEQ_H

#include "core/encseq_api.h"
#include "extended/wtree.h"

/* The <GtWtreeEncseq> class implements the <GtWtree> interface.
   This implementation represents the sequence part of an encoded sequence */
typedef struct GtWtreeEncseq GtWtreeEncseq;

/* Return a new <GtWtree> object, representing an <encseq>. */
GtWtree* gt_wtree_encseq_new(GtEncseq *encseq);

/* Maps <symbol> to a decoded character symbol as defined by the original
   alphabet <wtree> was built with. */
char     gt_wtree_encseq_unmap_decoded(GtWtree *wtree, GtWtreeSymbol symbol);

#endif
